#!/usr/bin/env python
# coding: utf-8

from datetime import datetime
import os

import matplotlib.pyplot as plt
import numpy as np
import xarray

import dplume



PATH = '/project/kug/smartcarb/results/Berlin/figures'


def main(time, tracer, ssp, ns=37, orbit=None, lon_eq=None, make_figure=True):

    q = 0.99
    nsat = 6


    # load results for 20 samples
    ts = dplume.io.read_results(tracer, ssp, ns=ns, q=q, nsat=nsat,
                                origin='Berlin')
    ts = dplume.io.filter_overlap(ts, nmax=100)

    ts = ts[ts.index == time]
    px = ts.detected_pixels.values
    TP = ts.CO2_TP.values
    PPV = ts.CO2_PPV.values

    if len(ts) != 20:
        raise RuntimeError("The data should have 20 samples.")

    print(tracer, ssp, ns)
    print('detect:\t %.0f +/- %.0f' % (px.mean(), px.std()))
    print('TP:\t %.0f +/- %.0f' % (TP.mean(), TP.std()))
    print('PPV:\t %.2f +/- %.2f' % (np.nanmean(PPV), np.nanstd(PPV)))
    print()


    if not make_figure:
        return


    for i in [np.argmin(px), np.argmin(np.abs(np.median(px) - px)),
              np.argmax(px)]:

        filenames = dplume.io.get_sample_filenames(time, tracer, ssp,
                                                   nsample=i, ns=ns,
                                                   orbit=orbit, lon_eq=lon_eq)
        filename = filenames[0]
        #print(i, os.path.basename(filename), len(filenames))

        data = xarray.open_dataset(filename)

        if ssp == 'S5':
            data7 = dplume.io.read_s7_for_s5_result(filename, 'Berlin')
        else:
            data7 = None

        filename = os.path.basename(filename).replace('.nc', '.png')
        filename = os.path.join(PATH, filename)

        dplume.vis.visualize(data, data7=data7, is_sentinel_5=(ssp=='S5'))
        plt.savefig(filename)



if __name__ == '__main__':
    
    # CO2: weak signal because of wind speed
    time = datetime(2015,7,2,11)
    orbit = 2714
    lon_eq = 1207

    # case: overview
    time = datetime(2015,4,21,11)
    orbit = 1640
    lon_eq = 0

    # CO2 gradient misfit
    time = datetime(2015,2,27,11)
    orbit = 850
    lon_eq = 401


    # Sentinel-7 cloud-free but Sentinel-5 cloudy
    time = datetime(2015,12,3,11)
    orbit = 5010
    lon_eq = 1207


    # Sentinel-7: plume shift
    time = datetime(2015,6,17,11)
    orbit = 2490
    lon_eq = 401
    make_figure = True

    cases = [
        #('CO2', 0.5, 37),
        #('CO2', 0.7, 37),
        #('CO2', 1.0, 37),
        ('NO2', 'low', 37),
        ('NO2', 'high', 37),
        ('NO2', 'S5', 5),
    ]

    for tracer, ssp, ns in cases:
        main(time, tracer, ssp, ns, make_figure=make_figure,
             lon_eq=lon_eq, orbit=orbit)


